helpers

package
v0.0.0-...-c34d2c7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 4, 2019 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SyncUser

func SyncUser(userUUID string) (err error)

SyncUser is a helper function for re-sending user info to tracking services

func TrackEvent

func TrackEvent(userUUID, eventName string) (err error)

TrackEvent is a helper function for tracking user events

func TrackEventFromMetadata

func TrackEventFromMetadata(md metadata.MD, eventName string) (err error)

TrackEventFromMetadata determines the current user from gRPC context metadata and tracks the event if it is an authenticated user

Types

This section is empty.

Jump to