package
Version:
v0.0.0-...-c34d2c7
Opens a new window with list of versions in this module.
Published: Sep 4, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
SyncUser is a helper function for re-sending user info to tracking services
func TrackEvent(userUUID, eventName string) (err error)
TrackEvent is a helper function for tracking user events
TrackEventFromMetadata determines the current user from gRPC context metadata
and tracks the event if it is an authenticated user
Source Files
¶
Click to show internal directories.
Click to hide internal directories.